@@ -13,6 +13,9 @@ class NSSM:
         # code below might be useless
         # if not isUserAdmin():
         #     runAsAdmin()
+    def updateService(self,name,executable,params=''):
+        self.setServiceExecutable(name,executable)
+        self.setServiceParams(name,params)
     def installService(self,name,executable,params=''):
         self.asAdmin()
         os.system('%s install %s "%s" "%s"'%(self.path,name,executable,params))
